@@ -7,7 +7,7 @@ use Moo;
 use Math::Trig qw(:pi);
 use POSIX qw(ceil);
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use constant K => pi / 180;
 
@@ -198,7 +198,7 @@ Data::Turtle - Turtle Movement and State Operations
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
@@ -228,7 +228,7 @@ version 0.0203
 This module enables basic turtle movement and state operations without
 requiring any particular graphics package.
 
-The methods don't draw anything.  They just set or output coordinates
+The methods don't draw anything. They just set or output coordinates
 and values for drawing by your favorite graphics package.
 
 For examples with L<GD> and L<Imager>, please see the files in the
@@ -258,7 +258,7 @@ Attributes:
 
 =item * width, height
 
-Drawing surface dimensions.  Defaults:
+Drawing surface dimensions. Defaults:
 
   width  = 500
   height = 500
@@ -269,7 +269,7 @@ Drawing surface dimensions.  Defaults:
 
 =item * x, y, heading
 
-Coordinate parameters.  Defaults:
+Coordinate parameters. Defaults:
 
   x       = width / 2
   y       = height / 2
@@ -281,9 +281,9 @@ Coordinate parameters.  Defaults:
 
 =item * pen_status, pen_color, pen_size
 
-Is the pen is up or down?  Default: 1 (down position)
+Is the pen is up or down? Default: 1 (down position)
 
-Pen properties.  Defaults: pen_color = the string 'black', pen_size = 1
+Pen properties. Defaults: pen_color = the string 'black', pen_size = 1
 
 =back
 
@@ -342,7 +342,7 @@ Set the turtle state with the given parameters.
   @line = $turtle->forward($steps);
 
 Move forward the given number of steps, and return a list defining a
-line is returned with these values:
+line with these values:
 
   x0, y0, x, y, pen_color, pen_size
 
@@ -351,7 +351,7 @@ line is returned with these values:
   @line = $turtle->backward($steps);
 
 Move backward the given number of steps, and return a list defining a
-line is returned with these values:
+line with these values:
 
   x0, y0, x, y, pen_color, pen_size
 
@@ -366,7 +366,7 @@ Reflect the heading (by multiplying by -1).
   @line = $turtle->goto($x, $y);
 
 Move the pen to the given coordinate, and return a list defining a
-line is returned with these values:
+line with these values:
 
   x0, y0, x, y, pen_color, pen_size
 
